@@ -1,5 +1,5 @@
 #probhat: Multivariate Generalized Kernel Smoothing and Related Statistical Methods
-#Copyright (C), Abby Spurdle, 2018 to 2021
+#Copyright (C), Abby Spurdle, 2019 to 2021
 
 #This program is distributed without any warranty.
 
@@ -15,30 +15,33 @@ pdfuv.cks = function (x, ..., w,
 	bw, smoothness=1,
 	kernel=BIWEIGHT.CKERNEL,
 	spline=TRUE, bw.method="ph.default", nc=30,
+	trtype="local",
 	Xlim = cbind (a, b), a=-Inf, b=Inf)
 {	.arg.error (...)
 	.cksuv (.pdfuv.cks.eval, .CV.pdfuv.cks,
-		FALSE, spline, nc, Xlim, bw.method, kernel, bw, smoothness, x, w)
+		FALSE, spline, nc, Xlim, bw.method, kernel, trtype, bw, smoothness, x, w)
 }
 
 cdfuv.cks = function (x, ..., w,
 	bw, smoothness=1,
 	kernel=BIWEIGHT.CKERNEL,
 	spline=TRUE, bw.method="ph.default", nc=30, tail="lower",
+	trtype="local",
 	Xlim = cbind (a, b), a=-Inf, b=Inf)
 {	.arg.error (...)
 	.cksuv (.cdfuv.cks.eval, .CV.cdfuv.cks,
-		TRUE, spline, nc, Xlim, bw.method, kernel, bw, smoothness, x, w, tail)
+		TRUE, spline, nc, Xlim, bw.method, kernel, trtype, bw, smoothness, x, w, tail)
 }
 
 qfuv.cks = function (x, ..., w,
 	bw, smoothness=1,
 	kernel=BIWEIGHT.CKERNEL,
 	bw.method="ph.default", nc=30,
+	trtype="local",
 	Xlim = cbind (a, b), a=-Inf, b=Inf)
 {	.arg.error (...)
 	.qfuv.cks (.cdfuv.cks.eval, .qfuv.cks.eval,
-		nc, Xlim, bw.method, kernel, bw, smoothness, x, w, tail="lower")
+		nc, Xlim, bw.method, kernel, trtype, bw, smoothness, x, w, tail="lower")
 }
 
 pdfmv.cks = function (x, ..., w,
@@ -66,10 +69,11 @@ pdfc.cks = function (x, ..., conditions, w,
 	kernel=BIWEIGHT.CKERNEL,
 	spline=TRUE, bw.method="ph.default", nc=30,
 	Xlim = cbind (a, b), a=-Inf, b=Inf,
-	preserve.range=FALSE, as.cset=FALSE, warning=TRUE)
+	preserve.range=FALSE, as.cset=FALSE, as.list.cset=FALSE, warning=TRUE)
 {	.arg.error (...)
 	.cksc.2 (.pdfc.cks.eval, .CV.pdfc.cks,
-		FALSE, spline, nc, preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w, as.cset, warning)
+		FALSE, spline, nc, preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w,
+		as.cset, as.list.cset, warning)
 }
 
 cdfc.cks = function (x, ..., conditions, w,
@@ -77,10 +81,11 @@ cdfc.cks = function (x, ..., conditions, w,
 	kernel=BIWEIGHT.CKERNEL,
 	spline=TRUE, bw.method="ph.default", nc=30, tail="lower",
 	Xlim = cbind (a, b), a=-Inf, b=Inf,
-	preserve.range=FALSE, as.cset=FALSE, warning=TRUE)
+	preserve.range=FALSE, as.cset=FALSE, as.list.cset=FALSE, warning=TRUE)
 {	.arg.error (...)
 	.cksc.2 (.cdfc.cks.eval, .CV.cdfc.cks,
-		TRUE, spline, nc, preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w, as.cset, warning, tail)
+		TRUE, spline, nc, preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w,
+		as.cset, as.list.cset, warning, tail)
 }
 
 qfc.cks = function (x, ..., conditions, w,
@@ -88,10 +93,11 @@ qfc.cks = function (x, ..., conditions, w,
 	kernel=BIWEIGHT.CKERNEL,
 	bw.method="ph.default", nc=30,
 	Xlim = cbind (a, b), a=-Inf, b=Inf,
-	preserve.range=FALSE, as.cset=FALSE, warning=TRUE)
+	preserve.range=FALSE, as.cset=FALSE, as.list.cset=FALSE, warning=TRUE)
 {	.arg.error (...)
 	.qfc.cks (.cdfc.cks.eval, .qfc.cks.eval,
-		nc, preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w, as.cset, warning, tail="lower")
+		nc, preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w,
+		as.cset, as.list.cset, warning, tail="lower")
 }
 
 pdfmvc.cks = function (x, ..., conditions, w,
@@ -99,10 +105,11 @@ pdfmvc.cks = function (x, ..., conditions, w,
 	kernel=BIWEIGHT.CKERNEL,
 	bw.method="ph.default",
 	Xlim = cbind (a, b), a=-Inf, b=Inf,
-	preserve.range=FALSE, as.cset=FALSE, warning=TRUE)
+	preserve.range=FALSE, as.cset=FALSE, as.list.cset=FALSE, warning=TRUE)
 {	.arg.error (...)
 	.cksmvc.2 (.pdfmvc.cks.eval, .CV.pdfmvc.cks, FALSE,
-		preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w, as.cset, warning)
+		preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w,
+		as.cset, as.list.cset, warning)
 }
 
 cdfmvc.cks = function (x, ..., conditions, w,
@@ -110,10 +117,11 @@ cdfmvc.cks = function (x, ..., conditions, w,
 	kernel=BIWEIGHT.CKERNEL,
 	bw.method="ph.default", tail="lower",
 	Xlim = cbind (a, b), a=-Inf, b=Inf,
-	preserve.range=FALSE, as.cset=FALSE, warning=TRUE)
+	preserve.range=FALSE, as.cset=FALSE, as.list.cset=FALSE, warning=TRUE)
 {	.arg.error (...)
 	.cksmvc.2 (.cdfmvc.cks.eval, .CV.cdfmvc.cks, TRUE,
-		preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w, as.cset, warning, tail)
+		preserve.range, conditions, Xlim, bw.method, kernel, bw, smoothness, x, w,
+		as.cset, as.list.cset, warning, tail)
 }
 
 chqf.cks = function (x, ..., w,
