@@ -1,5 +1,5 @@
 #probhat: Multivariate Generalized Kernel Smoothing and Related Statistical Methods
-#Copyright (C), Abby Spurdle, 2018 to 2021
+#Copyright (C), Abby Spurdle, 2019 to 2021
 
 #This program is distributed without any warranty.
 
@@ -16,7 +16,7 @@
 		stop ("spline models need >= 10 control points")
 }
 
-.cksuv = function (f, classes, is.cdf, is.spline, nc, XLIM, bw.method, kernel, bw, smoothness, x, w, tail)
+.cksuv = function (f, classes, is.cdf, is.spline, nc, XLIM, bw.method, kernel, trtype, bw, smoothness, x, w, tail)
 {   	xname = .varname (x)
 	.test.nc (nc)
 	x = .val.x.uv (x, TRUE)
@@ -43,45 +43,68 @@
 	.is.trunc = .is.trunc.uv (hbw, XLIM, xlim)
 	.any.trunc = any (.is.trunc)
 
-	.scalef = .xpnd = NA
+	.internalw = w
+	.internal.isw = is.weighted
+	.scalef = .xpnd = .constv = NA
+	.const.cdf.lower = 0
 	.any.trunc.lower = .is.trunc.lower = FALSE
 
 	if (.any.trunc)
 	{	.check.x.inside.uv (.is.trunc, XLIM, x)
-
 		xlim = .update.xlim (.is.trunc, XLIM, xlim)
-		.xpnd = .update.x.uv (.is.trunc, hbw, XLIM, n, x, w, is.weighted)
+	}
+	data = list (n=n, xlim=xlim, x=x, w=w)
+
+	if (! (trtype %in% c ("simple", "local", "reflect") ) )
+		stop ("trtype not simple, local or reflect")
+
+	if (.any.trunc)
+	{	.is.trunc.lower = .is.trunc.lower.side (rbind (.is.trunc), .low)
+		.any.trunc.lower = any (.is.trunc.lower)
 		if (is.cdf)
-		{	.is.trunc.lower = .is.trunc.lower.side (rbind (.is.trunc), .low)
-			.any.trunc.lower = any (.is.trunc.lower)
+		{	if (.low) u = XLIM [1]
+			else u = XLIM [2]
+		}
+
+		if (trtype == "simple")
+			.xpnd = data
+		else if (trtype == "local")
+		{	if (is.weighted) initw = w
+			else initw = rep (1 / n, n)
+
+			if (is.cdf && .any.trunc.lower)
+				.constv = .update.wkc.uv (.is.trunc.lower, bw, kernel@F, XLIM, n, x, .low)
+			locw =  .update.wk.uv (.is.trunc, bw, kernel@F, XLIM, n, x)
+			.internal.isw = TRUE
+			.internalw = initw * 1 / locw
 		}
 		else
-		{	subv = .pwith.eval.uv (bw, kernel@F, .xpnd$n, .xpnd$x, XLIM [1], XLIM [2],
+		{	.xpnd = .update.x.uv (.is.trunc, hbw, XLIM, n, x, w, is.weighted)
+			.internalw = .xpnd$w
+		}
+	
+		if (trtype != "local")
+		{	if (is.cdf && .any.trunc.lower)
+			{	.const.cdf.lower =
+					.cdfuv.cks.eval.scalar (is.weighted, kernel@F, bw, .xpnd$n, .xpnd$x, .xpnd$w, .low, NA, u)
+			}
+			subv = .pwith.eval.uv (bw, kernel@F, .xpnd$n, .xpnd$x, XLIM [1], XLIM [2],
 				is.weighted, .xpnd$w)
 			.scalef = 1 / subv
 		}
 	}
-	data = list (n=n, xlim=xlim, x=x, w=w)
 
 	sf = .EXTEND (f, classes,
-		.const.cdf.lower=0,
+		.internal.isw,
+		.constv,
+		.internalw,
+		.const.cdf.lower,
 		.any.trunc.lower, .is.trunc.lower,
 		.any.trunc, .is.trunc, .xpnd, .scalef,
 		.low,
 		xname, XLIM, is.spline=FALSE, is.weighted, tail, spline.function=NA, kernel,
+		trtype,
 		bw, smoothness, n0=n, data)
-	if (is.cdf)
-	{	if (.any.trunc)
-		{	if (.any.trunc.lower)
-			{	lo = sf (.cdf.lower.side (.low, rbind (xlim) ), .ignore.trunc=TRUE)
-				sf %$% ".const.cdf.lower" = lo
-			}
-			else
-				lo = 0
-			hi = sf (.cdf.upper.side (.low, rbind (xlim) ), .ignore.trunc=TRUE)
-			sf %$% ".scalef" = 1 / (hi - lo)
-		}
-	}
 	if (is.spline)
 	{	sf %$% "spline.function" = .spline (sf, is.cdf, nc, .low)
 		sf %$% "is.spline" = TRUE
@@ -116,34 +139,36 @@
 
 	if (missing (tail) )
 		.low = tail = NA
-	else if (init.class == "mv")
+	else if (is.cdf && init.class == "mv")
 	{	tail = .val.tail (tail, m)
 		.low = (tail == "lower")
 	}
 
 	if (init.class != "ch")
-	{	.any.trunc.lower = .is.trunc.lower = FALSE
+	{	.internalw = w
+		.internal.isw = is.weighted
 		XLIM = .val.XLIM.mv (XLIM, m)
 		.is.trunc = .is.trunc.mv (hbw, XLIM, xlim)
 		.any.trunc = any (.is.trunc)
 	
 		.scalef = .xpnd = NA
+		.constv = matrix (NA, 1, m)
+
 		if (.any.trunc)
 		{	.check.x.inside.mv (.is.trunc, XLIM, m, x)
-
 			xlim = .update.xlim (.is.trunc, XLIM, xlim)
-			.xpnd = .update.x.mv (.is.trunc, hbw, XLIM, n, m, x, w, is.weighted)
-
 			if (init.class == "mv")
 			{	if (is.cdf)
 				{	.is.trunc.lower = .is.trunc.lower.side (.is.trunc, .low)
 					.any.trunc.lower = any (.is.trunc.lower)
+					if (.any.trunc.lower)
+						.constv = .update.wkc.mv (.is.trunc.lower, bw, kernel@F, XLIM, n, m, x, .low)
 				}
-				else
-				{	subv = .pwith.eval.mv (bw, kernel@F, .xpnd$n, m, .xpnd$x, XLIM [,1], XLIM [,2],
-						is.weighted, .xpnd$w)
-					.scalef = 1 / subv
-				}
+				if (is.weighted) initw = w
+				else initw = rep (1 / n, n)
+				locw = .update.wk.mv (.is.trunc, bw, kernel@F, XLIM, n, m, x)
+				.internal.isw = TRUE
+				.internalw = initw / locw
 			}
 		}
 	}
@@ -151,23 +176,22 @@
 
 	sf = if (init.class == "mv")
 		.EXTEND (f, classes,
-			.any.trunc.lower, .is.trunc.lower,
-			.any.trunc, .is.trunc, .scalef, .xpnd,
+			.internalw, .internal.isw, .constv,
+			.any.trunc, .is.trunc, .scalef,
 			.low,
 			xnames, XLIM, is.weighted, tail, kernel, bw, smoothness, m, n0=n, data)
 	else if (init.class == "c")
 		.EXTEND (f, classes,
-			.const.cdf.lower=0,
-			.any.trunc.lower, .is.trunc.lower,
-			.any.trunc, .is.trunc, .scalef, .xpnd,
+			.internalw, .internal.isw, .constv,
+			.any.trunc, .is.trunc, .scalef,
 			.constant=NA, .v=NA, .low=NA,
 			M=NA, ncon=NA, xnames, XLIM,
 			is.spline=FALSE, is.weighted, tail, spline.function=NA, conditions=NA,
 			kernel, bw, smoothness, m, n0=0, data)
 	else if (init.class == "mvc")
 		.EXTEND (f, classes,
-			.any.trunc.lower, .is.trunc.lower,
-			.any.trunc, .is.trunc, .scalef, .xpnd,
+			.internalw, .internal.isw, .constv,
+			.any.trunc, .is.trunc, .scalef,
 			.constant=NA, .v=NA, .low=NA,
 			M=NA, ncon=NA, xnames, XLIM,
 			is.weighted, tail, conditions=NA,
@@ -175,14 +199,10 @@
 	else
 		.EXTEND (f, classes,
 			xnames, is.weighted, nc=NA, qf1=NA, kernel, bw, smoothness, m, n0=n, data)
-	if (is.cdf && init.class == "mv")
-	{	if (.any.trunc)
-			sf %$% ".scalef" = .cdf.scalef (sf, m)
-	}
 	sf
 }
 
-.cksc = function (f, is.cdf, is.spline, nc, preserve.range, conditions, as.cset, warning, init.class="c")
+.cksc = function (f, is.cdf, is.spline, nc, preserve.range, conditions, as.cset, as.list.cset, warning, init.class="c")
 {	m = f %$% "m"
 	if (missing (conditions) )
 		stop ("conditions required")
@@ -196,11 +216,6 @@
 	if (ncon < 0 || ncon > m - 1)
 		stop ("length (conditions) not in interval [0, m - 1]")
 	preserve.range = rep_len (preserve.range, M)
-	if (is.cdf)
-	{	tail = .val.tail (f %$% "tail", M)
-		f %$% ".low" = (tail == "lower")
-		f %$% "tail" = tail
-	}
 	if (ncon > 0)
 	{	names = colnames (conditions)
 		if (is.null (names) )
@@ -217,8 +232,8 @@
 			f %$% "smoothness" = (f %$% "smoothness")[J]
 
 			if (f %$% ".any.trunc")
-			{	f %$% ".is.trunc" = (f %$% ".is.trunc")[J,, drop=FALSE]
-				f %$% ".xpnd" = .sub.data.col (f %$% ".xpnd", J)
+			{	f %$% ".constv" = (f %$% ".constv")[,J, drop=FALSE]
+				f %$% ".is.trunc" = (f %$% ".is.trunc")[J,, drop=FALSE]
 			}
 			f %$% "data" = .sub.data.col (f %$% "data", J)
 		}
@@ -226,37 +241,45 @@
 	f %$% "M" = M
 	f %$% "ncon" = ncon
 	f %$% "conditions" = conditions
-	f %$% "n0" = f %$% "n"
+	f %$% "n0" = (f %$% "data")$n
 
 	CONS = 1:ncon
 	RVS = (ncon + 1):m
+	if (is.cdf)
+	{	f %$% ".constv" = (f %$% ".constv")[,RVS, drop=FALSE]
 
+		tail = .val.tail (f %$% "tail", M)
+		f %$% "tail" = tail
+		f %$% ".low" = (tail == "lower")
+	}
 	if (f %$% ".any.trunc")
-	{	.check.x.inside.mv ( (f %$% ".is.trunc")[CONS,, drop=FALSE], (f %$% "XLIM")[CONS,, drop=FALSE], ncon, conditions, "condition")
-
-		if (is.cdf)
-		{	f %$% ".is.trunc.lower" = .is.trunc.lower.side ( (f %$% ".is.trunc")[RVS,, drop=FALSE], f %$% ".low")
-			f %$% ".any.trunc.lower" = any (f %$% ".is.trunc.lower")
-		}
+	{	.check.x.inside.mv ( (f %$% ".is.trunc")[CONS,, drop=FALSE],
+		(f %$% "XLIM")[CONS,, drop=FALSE], ncon, conditions, "condition")
 	}
 
 	nnull = 0
 	nsets = nrow (conditions)
-
+	if (as.cset || nsets != 1)
+	{	if (! as.list.cset)
+			stop ("as.list.cset needs to be true, for cset(s)")
+	}
 	VF = vector ("list", nsets)
-	data0 = f %$% "data"
 	for (ith.set in seq_len (nsets) )
 	{	ith.conditions = conditions [ith.set,]
 		data = f %$% "data"
-		K = .con.sub (ncon, ith.conditions, f %$% "bw", data$n, data$x, data$w)
+		K = .con.sub (ncon, ith.conditions, f %$% "bw", data$n, data$x, data$w,
+			f %$% ".internal.isw", f %$% ".constv", f %$% ".internalw")
 		if (K$n == 0)
 			nnull = nnull + 1
 		else
 		{	new.f = f
 
+			new.f %$% ".constv" = K$.constv
+			new.f %$% ".internalw" = K$.internalw
 			data$n = K$n
 			data$x = K$x
 			data$w = K$w
+
 			xlim = data$xlim
 			for (j in 1:m)
 			{	if (j > ncon && preserve.range [j - ncon])
@@ -265,67 +288,34 @@
 					xlim [j,] = range (data$x [,j]) + c (-0.5, 0.5) * (new.f %$% "bw")[j]
 			}
 			if (f %$% ".any.trunc")
+			{	#xlim needs to be truncated, after updating above
 				xlim = .update.xlim (f %$% ".is.trunc", f %$% "XLIM", xlim)
+				if (is.cdf)
+				{	.is.trunc.lower = .is.trunc.lower.side ( (f %$% ".is.trunc")[RVS,, drop=FALSE], f %$% ".low")
+					.any.trunc.lower = any (.is.trunc.lower)
+					if (.any.trunc.lower)
+					{	new.f %$% ".constv" = .update.wkc.mv (
+							.is.trunc.lower, (f %$% "bw")[RVS], (f %$% "kernel")@F,
+							(f %$% "XLIM")[RVS,, drop=FALSE],
+							data$n, f %$% "M", data$x [,RVS, drop=FALSE], f %$% ".low")
+					}
+				}
+				if (f %$% "is.weighted") initw = data$w
+				else initw = rep (1 / data$n, data$n)
+				locw =  .update.wk.mv ( (f %$% ".is.trunc")[RVS,, drop=FALSE], (f %$% "bw")[RVS], (f %$% "kernel")@F,
+					(f %$% "XLIM")[RVS,, drop=FALSE], data$n, M, data$x [,RVS, drop=FALSE])
+				new.f %$% ".internal.isw" = TRUE
+				new.f %$% ".internalw" = initw / locw
+			}
 			data$xlim = xlim
 			new.f %$% "data" = data
 
-			if (f %$% ".any.trunc")
-			{	xpnd = f %$% ".xpnd"
-				K = .con.sub (ncon, ith.conditions, f %$% "bw", xpnd$n, xpnd$x, xpnd$w)
-				xpnd$n = K$n
-				xpnd$x = K$x
-				xpnd$w = K$w
-				new.f %$% ".xpnd" = xpnd
-				fdata = xpnd
-
-				. = attributes (new.f)
-				if (is.cdf)
-				{	if (init.class == "c")
-					{	if (.$.low) u = .$XLIM [m, 1]
-						else u = .$XLIM [m, 2]
-						new.f %$% "const.cdf.lower" =
-							.cdfuv.cks.eval.scalar (.$is.weighted, .$kernel@F, .$bw, xpnd$n, xpnd$x, xpnd$w, f %$% ".low", u)
-					}
-					else
-						new.f %$% "scalef" = 0
-				}
-				else
-				{	subv.top = .pwith.eval.mv (.$bw, .$kernel@F,
-						xpnd$n, m, xpnd$x, .$XLIM [,1], .$XLIM [,2],
-						.$is.weighted, xpnd$w)
-					subv.btm = .pwith.eval.mv (.$bw [CONS], .$kernel@F,
-						xpnd$n, ncon, xpnd$x [,CONS, drop=FALSE], .$XLIM [CONS, 1], .$XLIM [CONS, 2],
-						.$is.weighted, xpnd$w)
-					scalef = subv.btm / subv.top
-					new.f %$% ".scalef" = scalef
-				}
-			}
-			else
-				fdata = data
-
-			new.f %$% ".v" = .precompute.cksc.v (ncon, ith.conditions, (new.f %$% "kernel")@f, new.f %$% "bw", fdata$n, fdata$x)
-			new.f %$% ".constant" = .sumk (new.f %$% "is.weighted", fdata$n, fdata$w, new.f %$% ".v")
-			if (is.cdf)
-			{	if (f %$% ".any.trunc")
-				{	if (init.class == "c")
-					{	low = f %$% ".low"
-						if (f %$% ".any.trunc.lower")
-						{	xlim = data$xlim
-							lo = new.f (.cdf.lower.side (low, xlim [RVS,, drop=FALSE]), .ignore.trunc=TRUE)
-						}
-						else
-							lo = 0
-						hi = new.f (.cdf.upper.side (low, xlim [RVS,, drop=FALSE]), .ignore.trunc=TRUE)
-						new.f %$% ".const.cdf.lower" = lo
-						new.f %$% ".scalef" = 1 / (hi - lo)
-					}
-					else
-						new.f %$% ".scalef" = .cdf.scalef (new.f, M)
-				}
-			}
+			new.f %$% ".v" = .precompute.cksc.v (ncon, ith.conditions, (f %$% "kernel")@f, f %$% "bw",
+				data$n, data$x)
+			new.f %$% ".constant" = .sumk (f %$% "is.weighted", data$n, data$w, new.f %$% ".v")
 
 			if (init.class == "c" && is.spline)
-			{	new.f %$% "spline.function" = .spline (new.f, is.ccdf (new.f), nc, new.f %$% ".low")
+			{	new.f %$% "spline.function" = .spline (new.f, is.ccdf (new.f), nc, f %$% ".low")
 				new.f %$% "is.spline" = TRUE
 			}
 			VF [[ith.set]] = new.f
@@ -338,26 +328,26 @@
 	}
 	else
 	{	if (nnull > 0 && warning)
-			warning (sprintf ("%i null models, no observations within conditional windows", nnull) )
+			warning (sprintf ("%i null model(s), no observations within conditional windows", nnull) )
 		VF
 	}
 }
 
 .cksc.2 = function (f, classes, is.cdf,
-	is.spline, nc, preserve.range, conditions, XLIM, bw.method, kernel, bw, smoothness, x, w, as.cset, warning, tail)
+	is.spline, nc, preserve.range, conditions, XLIM, bw.method, kernel, bw, smoothness, x, w, as.cset, as.list.cset, warning, tail)
 {	.test.nc (nc)
-	f = .cksmv (f, classes, XLIM, bw.method, kernel, bw, smoothness, x, w, "c", FALSE, tail)
-	.cksc (f, is.cdf, is.spline, nc, preserve.range, conditions, as.cset, warning)
+	f = .cksmv (f, classes, XLIM, bw.method, kernel, bw, smoothness, x, w, "c", is.cdf, tail)
+	.cksc (f, is.cdf, is.spline, nc, preserve.range, conditions, as.cset, as.list.cset, warning)
 }
 
 .cksmvc.2 = function (f, classes, is.cdf,
-	preserve.range, conditions, XLIM, bw.method, kernel, bw, smoothness, x, w, as.cset, warning, tail)
-{	f = .cksmv (f, classes, XLIM, bw.method, kernel, bw, smoothness, x, w, "mvc", FALSE, tail)
-	.cksc (f, is.cdf, NULL, NULL, preserve.range, conditions, as.cset, warning, "mvc")
+	preserve.range, conditions, XLIM, bw.method, kernel, bw, smoothness, x, w, as.cset, as.list.cset, warning, tail)
+{	f = .cksmv (f, classes, XLIM, bw.method, kernel, bw, smoothness, x, w, "mvc", is.cdf, tail)
+	.cksc (f, is.cdf, NULL, NULL, preserve.range, conditions, as.cset, as.list.cset, warning, "mvc")
 }
 
-.qfuv.cks = function (F, F.inv, nc, XLIM, bw.method, kernel, bw, smoothness, x, w, tail)
-{	F = .cksuv (F, .CV.cdfuv.cks, TRUE, TRUE, nc, XLIM, bw.method, kernel, bw, smoothness, x, w, tail)
+.qfuv.cks = function (F, F.inv, nc, XLIM, bw.method, kernel, trtype, bw, smoothness, x, w, tail)
+{	F = .cksuv (F, .CV.cdfuv.cks, TRUE, TRUE, nc, XLIM, bw.method, kernel, trtype, bw, smoothness, x, w, tail)
 	attributes (F.inv) = attributes (F)
 	F.inv %$% "class" = .CV.qfuv.cks
 	F.inv %$% "spline.function" =
@@ -365,8 +355,8 @@
 	F.inv
 }
 
-.qfc.cks = function (F, F.inv, nc, preserve.range, conditions, XLIM, bw.method, kernel, bw, smoothness, x, w, as.cset, warning, tail)
-{	F = .cksc.2 (F, .CV.cdfc.cks, TRUE, TRUE, nc, preserve.range, conditions, XLIM, bw.method, kernel, bw, smoothness, x, w, as.cset, warning, tail)
+.qfc.cks = function (F, F.inv, nc, preserve.range, conditions, XLIM, bw.method, kernel, bw, smoothness, x, w, as.cset, as.list.cset, warning, tail)
+{	F = .cksc.2 (F, .CV.cdfc.cks, TRUE, TRUE, nc, preserve.range, conditions, XLIM, bw.method, kernel, bw, smoothness, x, w, as.cset, as.list.cset, warning, tail)
 	if (is.null (F) )
 		NULL
 	else if (is.ccdf (F) )
@@ -406,7 +396,7 @@
 	if (is.na (conditions [1]) )
 		K = list (n = data$n, x = data$x, w = data$w)
 	else
-	{	K = .con.sub (J - 1, conditions, .$bw, data$n, data$x, data$w)
+	{	K = .con.sub (J - 1, conditions, .$bw, data$n, data$x, data$w, .$is.weighted)
 		xlim [J,] = range (K$x [,J]) + c (-0.5, 0.5) * .$bw [J]
 	}
 	data = list (
@@ -431,13 +421,20 @@
 	F.inv
 }
 
-.con.sub = function (ncon, conditions, bw, n, x, w)
+.con.sub = function (ncon, conditions, bw, n, x, w, isw, .constv=NULL, .internalw=NULL)
 {	I = rep (TRUE, n)
 	for (j in seq_len (ncon) )
 	{	xlim = conditions [j] + c (-0.5, 0.5) * bw [j]
 		I = (I & x [,j] >= xlim [1] & x [,j] <= xlim [2])
 	}
-	if (! is.na (w [1]) )
+	if (isw)
+	{	if (! is.null (.constv) )
+		{	if (nrow (.constv) > 1)
+				.constv = .constv [I,, drop=FALSE]
+		}
+		if (! is.null (.internalw) )
+			.internalw = .internalw [I]
 		w = w [I]
-	list (n = sum (I), x = x [I,, drop=FALSE], w=w)
+	}
+	list (n = sum (I), x = x [I,, drop=FALSE], w=w, .constv=.constv, .internalw=.internalw)
 }
